@@ -12,7 +12,7 @@ ASSETS_URL = getattr(settings, 'SCSS_ASSETS_URL',
                      os.path.join(settings.MEDIA_URL, 'assets'))
 SCSS_COMPRESS = getattr(settings, 'SCSS_COMPRESS', True)
 SCSS_DEBUG_INFO = getattr(settings, 'SCSS_DEBUG_INFO', True)
-SCSS_REBUILD = getattr(settings, 'SCSS_REBUILD', True)
+SCSS_REBUILD = getattr(settings, 'SCSS_REBUILD', False)
 COFFEE_OUTPUT = getattr(settings, 'COFFEE_OUTPUT', 'js')
-COFFEE_REBUILD = getattr(settings, 'COFFEE_REBUILD', True)
-LESS_REBUILD = getattr(settings, 'LESS_REBUILD', True)
+COFFEE_REBUILD = getattr(settings, 'COFFEE_REBUILD', False)
+LESS_REBUILD = getattr(settings, 'LESS_REBUILD', False)
